@@ -1,5 +1,6 @@
 
 
+import rich
 import json
 from twisted import logger
 from twisted.internet.defer import inlineCallbacks
@@ -36,6 +37,9 @@ class SysinfoContainer(SysInfoBase):
         sysinfo = yield self.render()
         self.log.info("System Information : {sysinfo}",
                       sysinfo=json.dumps(sysinfo, indent=2))
+        if hasattr(self._actual, 'render_bg_providers'):
+            self.log.info("Background Providers: {bg_providers}",
+                          bg_providers=json.dumps(self._actual.render_bg_providers(), indent=2))
 
 
 class SysinfoMixin(BaseShellMixin):
