@@ -13,6 +13,21 @@ from twisted.internet import threads
 from twisted.internet.defer import inlineCallbacks
 
 
+class CustomStatusBlock(SysInfoBase):
+    keys = []
+
+    def __init__(self, actual, post_read=None):
+        super(CustomStatusBlock, self).__init__(actual)
+        self._post_read = post_read
+
+    def install(self):
+        super(CustomStatusBlock, self).install()
+        for x in self.keys:
+            if not hasattr(self, x):
+                setattr(self, x, None)
+        self._items = {x: x for x in self.keys}
+
+
 class StatusInfo(SysInfoBase):
     def __init__(self, *args):
         super(StatusInfo, self).__init__(*args)
@@ -38,6 +53,10 @@ class StatusInfo(SysInfoBase):
             'temperature': temperature,
         }
 
+    def register_status_block(self, name, block):
+        block.install()
+        self._items[name] = block
+
     @inlineCallbacks
     def _uptime(self):
         boot_time = yield threads.deferToThread(psutil.boot_time)
